/*!
 * \file main.c
 * \brief OLED C Click example
 *
 * # Description
 * This demo demonstrates the use of the OLED C click board and the control of
 * the OLED C display.
 *
 * The demo application is composed of two sections :
 *
 * ## Application Init
 * Initializes driver init and OLED C init and sets full screen on white color
 * with writting demo text.
 *
 * ## Application Task
 * This function is composed of three sections :
 *  -  Display demo rectangle.
 *  -  Display demo line.
 *  -  Display demo image.
 *
 * \author Nemanja Medakovic
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "fonts.h"
#include "images.h"
#include "board.h"
#include "oledc.h"


// ------------------------------------------------------------------ VARIABLES

static oledc_t oledc;

// ------------------------------------------------------------------ CONSTANTS

static const uint8_t text1[ 7 ] = { 'H','e','l','l','o',',',0 };
static const uint8_t text2[ 17 ] = { 't','h','i','s',' ','i','s',' ','t','h',
                                     'e',' ','d','e','m','o',0 };
static const uint8_t text3[ 17 ] = { 'f','o','r',' ','O','L','E','D',' ','C',
                                     ' ','c','l','i','c','k',0 };

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init( void )
{
    oledc_cfg_t oledc_cfg;

    //  Initialize OLED C click context on mikroBUS 1.
    oledc_cfg_setup( &oledc_cfg );
    OLEDC_MAP_MIKROBUS( oledc_cfg, MIKROBUS_1 );
    oledc_init( &oledc, &oledc_cfg );
    oledc_default_cfg( &oledc );

    oledc_fill_screen( &oledc, 0xFFFF );

    oledc_set_font( &oledc, guiFont_Tahoma_8_Regular, 0, OLEDC_FO_HORIZONTAL );
    oledc_text( &oledc, text1, 15, 10 );
    oledc_text( &oledc, text2, 5, 30 );
    oledc_text( &oledc, text3, 5, 45 );

    Delay_ms( 1000 );
}

void application_task( void )
{
    oledc_fill_screen( &oledc, 0xFFFF );
    Delay_ms( 100 );

    //  Rectangle demo.
    oledc_rectangle( &oledc, 0, 0, 96, 96, 0xF000 );
    Delay_ms( 500 );
    oledc_rectangle( &oledc, 5, 5, 91, 91, 0xFF00 );
    Delay_ms( 500 );
    oledc_rectangle( &oledc, 10, 10, 86, 86, 0x00F0 );
    Delay_ms( 500 );
    oledc_rectangle( &oledc, 15, 15, 81, 81, 0x0F0F );
    Delay_ms( 500 );
    oledc_rectangle( &oledc, 20, 20, 76, 76, 0xF000 );
    Delay_ms( 500 );
    oledc_rectangle( &oledc, 25, 25, 71, 71, 0xFF00 );
    Delay_ms( 100 );

    //  Line demo.
    oledc_rectangle( &oledc, 25, 25, 71, 27, 0 );
    Delay_ms( 100 );
    oledc_rectangle( &oledc, 25, 71, 71, 73, 0 );
    Delay_ms( 100 );
    oledc_rectangle( &oledc, 25, 25, 27, 71, 0 );
    Delay_ms( 100 );
    oledc_rectangle( &oledc, 68, 25, 71, 71, 0 );
    Delay_ms( 3000 );


    //  Image demo.
    oledc_image( &oledc, me_logo_bmp, 0, 0 );
    Delay_ms( 2000 );
}

void main( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
